SystemOrganization addCategory: #'OCMS-Kernel'!

Object subclass: #Courseware
	instanceVariableNames: 'id title description summary coursewareType owner reference tag classification author creationDateTime modificationDateTime cataloguingData license size comment score permission enabled downloadCounter file'
	classVariableNames: 'CoursewareTypeList'
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!Courseware commentStamp: 'HAS 4/28/2013 17:10' prior: 0!
Contains information about courseware

Instance variables:
	id <Long>										Unique identification
	title <String>										Title
	description <String>								Description
	summary <String>								A summary of the courseware's contents (optional)
	coursewareType <Symbol>						Type of courseware getting from CoursewareTypeSet class variable
	owner <User>									User that upload the courseware	
	reference <String>								Information about authors, journal, url, related courseware,...
	tag <List of: Tag>								A sorted list of tags related
	classification <List of: Discipline>					Disciplines/Areas related to the courseware
	author <List of: String>							Author(s) of the courseare in a ordered list
	creationDateTime <DateAndTime>					Date and time in which the courseware was uploaded
	modificationDateTime <DateAndTime>				Date and time of the last modification of the courseware
	cataloguingData <String>							Information about cataloguing data.
	license <LicenseType>							Type of license described in LicenseTypeSet class variable
	size <Integer>									Size of the courseware in K bytes
	comment <List of: Comment>						A list of comments of the courseware
	score <Map of: User and Float>					A map representing the score atributed by each user
	permission <Map of: User and PermissionType>	A map associating user and type of permission that they have
	enabled <Boolean>								A flag that indicates if the courseware is enable or not
	downloadCounter <Integer>						Number of downloads of the courseware
	file <File>										File name and extension of courseware!

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/30/2013 10:51'!
CoursewareTypeList
	^ CoursewareTypeList! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 16:49'!
author
	^ author! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 16:50'!
author: anOrderedCollectionString
	author := anOrderedCollectionString! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 16:58'!
cataloguingData
	^ cataloguingData! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 16:58'!
cataloguingData: aString
	cataloguingData := aString! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 16:42'!
classification
	^classification! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:06'!
classification: aSortedCollectionDiscipline
	classification := aSortedCollectionDiscipline! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:01'!
comment
	^ comment! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:01'!
comment: aOrderedCollectionComment
	comment := aOrderedCollectionComment! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/27/2013 15:22'!
coursewareType
	^ coursewareType! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/30/2013 11:03'!
coursewareType: aSymbol
	(CoursewareTypeList includes: aSymbol)
		ifTrue:[coursewareType := aSymbol]
		ifFalse:[self error: 'This CoursewareType does not exist']! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 16:57'!
creationDateTime
	^ creationDateTime! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 16:57'!
creationDateTime: aDateAndTime
	creationDateTime := aDateAndTime! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/27/2013 15:18'!
description
	^ description! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/27/2013 15:19'!
description: aString
	description := aString! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:08'!
downloadCounter
	^ downloadCounter! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:08'!
downloadCounter: anInteger
	downloadCounter := anInteger! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:04'!
enabled
	^ enabled! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:04'!
enabled: aBoolean
	enabled := aBoolean! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:09'!
file
	^ file! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:09'!
file: aFile
	file := aFile! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/27/2013 12:18'!
id
	^ id! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 18:29'!
id: anInteger
	(anInteger isInteger)
	ifTrue:[id := anInteger]
	ifFalse:[self error: 'The value must be an integer']! !

!Courseware methodsFor: 'initialize' stamp: 'HAS 4/30/2013 10:47'!
initialize
	CoursewareTypeList := #(Audio Code Exercise Program Slide Text Video).! !

!Courseware methodsFor: 'testing' stamp: 'HAS 4/28/2013 19:54'!
isCourseware
	^true! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 16:59'!
license
	^ license! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 16:59'!
license: aLicense
	license := aLicense! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/29/2013 19:50'!
modificationDateTime
	^ modificationDateTime! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/29/2013 19:50'!
modificationDateTime: aDateAndTime
	modificationDateTime := aDateAndTime! !

!Courseware methodsFor: 'instance creation' stamp: 'HAS 4/30/2013 10:48'!
new
	| newCourseware |
	
	newCourseware := super.
	newCourseware initialize.
	^newCourseware
! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 01:09'!
owner
	^ owner! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 07:44'!
owner: aUser
	owner := aUser! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:03'!
permission
	^ permission! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:05'!
permission: aMapOfUserAndPermissionType
	permission := aMapOfUserAndPermissionType! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 07:58'!
reference
	^ reference! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 07:59'!
reference: aString
	reference := aString! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:01'!
score
	^ score! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:05'!
score: aMapOfUserAndFloat
	score := aMapOfUserAndFloat! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:00'!
size
	^ size! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:00'!
size: aFloat
	size := aFloat! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/27/2013 15:20'!
summary
	^ summary! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/27/2013 15:19'!
summary: aString
	summary := aString! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 16:40'!
tag
	^tag! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/29/2013 21:09'!
tag: aOrderedCollectionTag
	| tagVariable |
	(aOrderedCollectionTag isMemberOf: OrderedCollection)
		ifFalse: [self error: 'This method must receives a OrderedCollection of Tag']
		ifTrue: [(aOrderedCollectionTag isEmpty not)
					ifFalse: [self error: 'This method must receives a OrderedCollection not empty']
					ifTrue: [tagVariable := aOrderedCollectionTag at: 1.
							(tagVariable isTag)
								ifTrue: [tag := aOrderedCollectionTag]
								ifFalse: [self error: 'This method must receives a OrderedCollection of Tag']
					]
		]! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/27/2013 14:00'!
title
	^ title! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:38'!
title: anString
	title := anString! !

Object subclass: #CoursewareManager
	instanceVariableNames: 'courseware'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!CoursewareManager commentStamp: 'HAS 4/29/2013 10:31' prior: 0!
This class manages coursewares, which include methods to search, edit and classify a courseware.

	courseware <Courseware>	Represent a courseware!

!CoursewareManager methodsFor: 'accessing' stamp: 'HAS 4/29/2013 10:32'!
courseware
	^ courseware! !

!CoursewareManager methodsFor: 'accessing' stamp: 'HAS 4/29/2013 10:33'!
courseware: aCourseware
	courseware := aCourseware! !

!CoursewareManager methodsFor: 'accessing' stamp: 'HAS 4/29/2013 11:14'!
getMaxCoursewareId
	| maxCoursewareId |
	
	"get max id from DB instead of the below line"
	maxCoursewareId := 10.
	^ maxCoursewareId! !

!CoursewareManager methodsFor: 'accessing' stamp: 'HAS 4/29/2013 19:50'!
includeCourseware: aTitle description: aDescription summary: aSummary coursewareType: aCoursewareType reference: aReference owner: aOwner tag: aTag classification: aListDiscipline author: aListAuthor cataloguingData: aCataloguingData license: aLicenseType size: aSize permission: aMapUserPermissionType file: aFile

| coursewareTemp |
coursewareTemp := Courseware new.
coursewareTemp id: self incrementCoursewareId.
coursewareTemp title: aTitle.
coursewareTemp description: aDescription.
coursewareTemp summary: aSummary.
coursewareTemp coursewareType: aCoursewareType.
coursewareTemp owner: aOwner.
coursewareTemp reference: aReference.
coursewareTemp tag: aTag.
coursewareTemp classification: aListDiscipline.
coursewareTemp author: aListAuthor.
coursewareTemp creationDateTime: DateAndTime now.
coursewareTemp modificationDateTime: nil.
coursewareTemp cataloguingData: aCataloguingData.
coursewareTemp license: aLicenseType.
coursewareTemp size: aSize.
coursewareTemp comment: nil.
coursewareTemp score: nil.
coursewareTemp permission: aMapUserPermissionType.
coursewareTemp enabled: true.
coursewareTemp downloadCounter: 0.
coursewareTemp file: aFile.
courseware := coursewareTemp.! !

!CoursewareManager methodsFor: 'accessing' stamp: 'HAS 4/29/2013 11:12'!
incrementCoursewareId
	| maxCoursewareId |
	
	maxCoursewareId := self getMaxCoursewareId.
	^ maxCoursewareId + 1! !

Object subclass: #Tag
	instanceVariableNames: 'name relatedTag'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!Tag commentStamp: 'HAS 4/28/2013 16:34' prior: 0!
Store the tags used to classify courseware.

	name <String>							Name of the tag.
	relatedTag <OrderedCollection of: Tag>		Contains the related tags.!

!Tag methodsFor: 'testing' stamp: 'HAS 4/28/2013 19:52'!
isTag
	^ true! !

!Tag methodsFor: 'accessing' stamp: 'HAS 4/28/2013 15:54'!
name
	^name! !

!Tag methodsFor: 'accessing' stamp: 'HAS 4/28/2013 15:59'!
name: aString
	"Verify if the tag already exists"
	name := aString
	! !

!Tag methodsFor: 'accessing' stamp: 'HAS 4/28/2013 16:05'!
relatedTag
	^relatedTag! !

!Tag methodsFor: 'accessing' stamp: 'HAS 4/29/2013 21:04'!
relatedTag: aOrderedCollection
	relatedTag := aOrderedCollection
	! !
